@@ -5,7 +5,7 @@ from .util import *
 
 class REDSZipReader(VideoReader):
     def __init__(self, zip_path: str, root: str):
-        """Read a Vimeo dataset zip file.
+        """Read a REDS dataset zip file.
         :param zip_path: path to REDS dataset zip file.
         :param root: path to REDS dataset file in zip. its sub dir should be <video index>/<frame index>.png. e.g. "test/test_sharp_bicubic/X4" in test_sharp_bicubic.zip
         """
@@ -31,8 +31,14 @@ class REDSZipReader(VideoReader):
         path = path[0:-1] if path[-1] == "/" else path
         return path
 
-    def read_images(self, paths: [str]) -> [np.ndarray]:
-        return [self.reader.read_image(self.root + self._format_path(path)) for path in paths]
+    def read_images(self, paths: (str, [str]), flag='unchanged', channel_order='bgr', backend=None) -> [np.ndarray]:
+        assert isinstance(paths, (str, list)), 'Paths must be a list or str type!'
+        if isinstance(paths, str):
+            paths = [paths]
+        return [
+            self.reader.read_image(self.root + self._format_path(path), flag, channel_order, backend)
+            for path in paths
+        ]
 
     def list_videos(self) -> [[str]]:
         return parse_video_list_from_image_list([p.replace(self.root, '') for p in self.reader.list_images(self.root)])
